==> inventive-inventory-1.3.2-sources.jar: net/inventive_mods/inventive_inventory/features/profiles/gui/render_state/ProfileScreenBackgroundGuiElementRenderState.java <==
package net.inventive_mods.inventive_inventory.features.profiles.gui.render_state;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.minecraft.class_10799;
import net.minecraft.class_11231;
import net.minecraft.class_11244;
import net.minecraft.class_332;
import net.minecraft.class_4588;
import net.minecraft.class_8030;
import org.jetbrains.annotations.Nullable;
import org.joml.Matrix3x2f;

public record ProfileScreenBackgroundGuiElementRenderState(RenderPipeline pipeline, class_11231 textureSetup, Matrix3x2f pose, float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3, int color, @Nullable class_8030 scissorArea, @Nullable class_8030 bounds) implements class_11244 {
    public ProfileScreenBackgroundGuiElementRenderState(class_332 context, float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3, int color) {
        this(class_10799.field_56879, class_11231.method_70899(), context.method_51448(), x0, y0, x1, y1, x2, y2, x3, y3, color, context.field_44659.method_70863(), createBounds(context.method_51448(), context.field_44659.method_70863()));
    }

    public void method_70917(class_4588 vertices, float depth) {
        vertices.method_70815(this.pose(), this.x0(), this.y0(), depth).method_39415(this.color());
        vertices.method_70815(this.pose(), this.x1(), this.y1(), depth).method_39415(this.color());
        vertices.method_70815(this.pose(), this.x2(), this.y2(), depth).method_39415(this.color());
        vertices.method_70815(this.pose(), this.x3(), this.y3(), depth).method_39415(this.color());
    }

    @Nullable
    private static class_8030 createBounds(Matrix3x2f pose, @Nullable class_8030 scissorArea) {
        new class_8030(0, 0, InventiveInventory.getScreen().field_22789, InventiveInventory.getScreen().field_22790);
        class_8030 screenRect = (new class_8030(0, 0, InventiveInventory.getScreen().field_22789, InventiveInventory.getScreen().field_22790)).method_71523(pose);
        return scissorArea != null ? scissorArea.method_49701(screenRect) : screenRect;
    }
}

==> inventive-inventory-1.3.3-sources.jar: net/inventive_mods/inventive_inventory/features/profiles/gui/render_state/ProfileScreenBackgroundGuiElementRenderState.java <==
package net.inventive_mods.inventive_inventory.features.profiles.gui.render_state;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.minecraft.class_10799;
import net.minecraft.class_11231;
import net.minecraft.class_11244;
import net.minecraft.class_332;
import net.minecraft.class_4588;
import net.minecraft.class_8030;
import org.jetbrains.annotations.Nullable;
import org.joml.Matrix3x2f;

public record ProfileScreenBackgroundGuiElementRenderState(RenderPipeline pipeline, class_11231 textureSetup, Matrix3x2f pose, float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3, int color, @Nullable class_8030 scissorArea, @Nullable class_8030 bounds) implements class_11244 {
    public ProfileScreenBackgroundGuiElementRenderState(class_332 context, float x0, float y0, float x1, float y1, float x2, float y2, float x3, float y3, int color) {
        this(class_10799.field_56879, class_11231.method_70899(), context.method_51448(), x0, y0, x1, y1, x2, y2, x3, y3, color, context.field_44659.method_70863(), createBounds(context.method_51448(), context.field_44659.method_70863()));
    }

    public void method_70917(class_4588 vertices) {
        vertices.method_70815(this.pose(), this.x0(), this.y0()).method_39415(this.color());
        vertices.method_70815(this.pose(), this.x1(), this.y1()).method_39415(this.color());
        vertices.method_70815(this.pose(), this.x2(), this.y2()).method_39415(this.color());
        vertices.method_70815(this.pose(), this.x3(), this.y3()).method_39415(this.color());
    }

    @Nullable
    private static class_8030 createBounds(Matrix3x2f pose, @Nullable class_8030 scissorArea) {
        new class_8030(0, 0, InventiveInventory.getScreen().field_22789, InventiveInventory.getScreen().field_22790);
        class_8030 screenRect = (new class_8030(0, 0, InventiveInventory.getScreen().field_22789, InventiveInventory.getScreen().field_22790)).method_71523(pose);
        return scissorArea != null ? scissorArea.method_49701(screenRect) : screenRect;
    }
}
